@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -138,6 +138,34 @@ class TiwClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeQualityMetrics(self, request):
+        """查询互动白板质量数据
+
+        :param request: Request instance for DescribeQualityMetrics.
+        :type request: :class:`tencentcloud.tiw.v20190919.models.DescribeQualityMetricsRequest`
+        :rtype: :class:`tencentcloud.tiw.v20190919.models.DescribeQualityMetricsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeQualityMetrics", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeQualityMetricsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeTranscode(self, request):
         """查询文档转码任务的执行进度与转码结果
 
@@ -250,6 +278,62 @@ class TiwClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeWhiteboardPush(self, request):
+        """查询推流任务状态与结果
+
+        :param request: Request instance for DescribeWhiteboardPush.
+        :type request: :class:`tencentcloud.tiw.v20190919.models.DescribeWhiteboardPushRequest`
+        :rtype: :class:`tencentcloud.tiw.v20190919.models.DescribeWhiteboardPushResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeWhiteboardPush", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeWhiteboardPushResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeWhiteboardPushCallback(self, request):
+        """查询白板推流回调地址
+
+        :param request: Request instance for DescribeWhiteboardPushCallback.
+        :type request: :class:`tencentcloud.tiw.v20190919.models.DescribeWhiteboardPushCallbackRequest`
+        :rtype: :class:`tencentcloud.tiw.v20190919.models.DescribeWhiteboardPushCallbackResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeWhiteboardPushCallback", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeWhiteboardPushCallbackResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def PauseOnlineRecord(self, request):
         """暂停实时录制
 
@@ -474,6 +558,62 @@ class TiwClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def SetWhiteboardPushCallback(self, request):
+        """设置白板推流回调地址，回调数据格式请参考文档：https://cloud.tencent.com/document/product/1137/40257
+
+        :param request: Request instance for SetWhiteboardPushCallback.
+        :type request: :class:`tencentcloud.tiw.v20190919.models.SetWhiteboardPushCallbackRequest`
+        :rtype: :class:`tencentcloud.tiw.v20190919.models.SetWhiteboardPushCallbackResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("SetWhiteboardPushCallback", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.SetWhiteboardPushCallbackResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def SetWhiteboardPushCallbackKey(self, request):
+        """设置白板推流回调鉴权密钥，回调鉴权方式请参考文档：https://cloud.tencent.com/document/product/1137/40257
+
+        :param request: Request instance for SetWhiteboardPushCallbackKey.
+        :type request: :class:`tencentcloud.tiw.v20190919.models.SetWhiteboardPushCallbackKeyRequest`
+        :rtype: :class:`tencentcloud.tiw.v20190919.models.SetWhiteboardPushCallbackKeyResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("SetWhiteboardPushCallbackKey", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.SetWhiteboardPushCallbackKeyResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def StartOnlineRecord(self, request):
         """发起一个实时录制任务
 
@@ -502,6 +642,34 @@ class TiwClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def StartWhiteboardPush(self, request):
+        """发起一个白板推流任务
+
+        :param request: Request instance for StartWhiteboardPush.
+        :type request: :class:`tencentcloud.tiw.v20190919.models.StartWhiteboardPushRequest`
+        :rtype: :class:`tencentcloud.tiw.v20190919.models.StartWhiteboardPushResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("StartWhiteboardPush", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.StartWhiteboardPushResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def StopOnlineRecord(self, request):
         """停止实时录制
 
@@ -523,6 +691,34 @@ class TiwClient(AbstractClient):
                 message = response["Response"]["Error"]["Message"]
                 reqid = response["Response"]["RequestId"]
                 raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def StopWhiteboardPush(self, request):
+        """停止白板推流任务
+
+        :param request: Request instance for StopWhiteboardPush.
+        :type request: :class:`tencentcloud.tiw.v20190919.models.StopWhiteboardPushRequest`
+        :rtype: :class:`tencentcloud.tiw.v20190919.models.StopWhiteboardPushResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("StopWhiteboardPush", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.StopWhiteboardPushResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
